# Inovopy 
![Static Badge](https://img.shields.io/badge/PyPI-inovopy-blue)
[![Static Badge](https://img.shields.io/badge/docs-page-red)](https://dizzyi.github.io/inovopy/)

## Installation
```bash
pip install inovopy
```